package com.upay.sdk.myexecuter;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.parser.Feature;
import com.upay.sdk.ConfigurationUtils;
import com.upay.sdk.Constants;
import com.upay.sdk.HttpClientUtils;
import com.upay.sdk.core.CipherWrapper;
import com.upay.sdk.exception.UnknownException;
import com.upay.sdk.executer.Executer;
import com.upay.sdk.onlinepay.builder.OrderBuilder;
import com.upay.sdk.onlinepay.builder.QueryBuilder;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class MyOnlinePayOrderExecuter extends Executer{
    static final Logger LOGGER = LoggerFactory.getLogger(MyOnlinePayOrderExecuter.class);
    public String bothOrder(OrderBuilder builder) {
        String retValue = "";
        try {
            JSONObject requestData = builder.bothEncryptBuild();
            LOGGER.debug("requestData:[" + requestData.toJSONString() + "]");
            String responseStr = HttpClientUtils.post3(ConfigurationUtils.getOnlinePayOrderUrl(), requestData);
            LOGGER.info("responseStr :{}", responseStr);
            JSONObject responseData = JSONObject.parseObject(responseStr, new Feature[]{Feature.SortFeidFastMatch});
            String status = responseData.getString(Constants.STATUS);
            if (Constants.ERROR.equals(status)) {
                //直接返回status=ERROR ，不需要解密验签
                return responseData.toJSONString();
            } else {
                responseData = CipherWrapper.bothDecryptWrap(responseData);
                LOGGER.debug("responseStr:[" + responseData + "]");
                if (Constants.ERROR.equals(responseData.getString("status"))) {
                    //解密后status=ERROR ，不需要验签
                    return responseData.toJSONString();
                }else{
                    //解密后，非status=ERROR ，需要验签
                    this.bothVerifyHmacOrder(responseData);
                    return responseData.toJSONString();
                }
            }
        } catch (Exception var7) {
            LOGGER.error("request order exception", var7);
            throw new UnknownException(var7);
        }
    }

    public String bothQuery(QueryBuilder builder) {
            try {
                JSONObject requestData = builder.bothEncryptBuild();
                LOGGER.debug("requestData:[" + requestData + "]");
                String responseStr = HttpClientUtils.post3(ConfigurationUtils.getOnlinePayQueryUrl(), requestData);
                JSONObject responseData = JSONObject.parseObject(responseStr, new Feature[]{Feature.SortFeidFastMatch});
                String status = responseData.getString(Constants.STATUS);
                if (Constants.ERROR.equals(status)) {
                    //直接返回status=ERROR ，不需要解密验签
                    LOGGER.debug("decrypt responseData : {}", responseData);
                    return responseData.toJSONString();
                } else {
                    responseData = CipherWrapper.bothDecryptWrap(responseData);
                    LOGGER.debug("responseStr:[" + responseData + "]");
                    if (Constants.ERROR.equals(responseData.getString("status"))) {
                        //解密后status=ERROR ，不需要验签
                        return responseData.toJSONString();
                    }else{
                        //解密后，非status=ERROR ，需要验签
                        this.bothVerifyHmacOrder(responseData);
                        return responseData.toJSONString();
                    }
                }
            } catch (Exception var7) {
                LOGGER.error("request order exception", var7);
                throw new UnknownException(var7);
            }

    }

}
