package com.upay.sdk.onlinepay;


import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.upay.sdk.entity.*;
import com.upay.sdk.exception.HmacVerifyException;
import com.upay.sdk.exception.RequestException;
import com.upay.sdk.exception.ResponseException;
import com.upay.sdk.exception.UnknownException;
import com.upay.sdk.executer.ResultListenerAdpater;
import com.upay.sdk.onlinepay.builder.OrderBuilder;
import com.upay.sdk.onlinepay.builder.OrderResponse;
import com.upay.sdk.onlinepay.executer.OnlinePayOrderExecuter;
import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import org.apache.commons.codec.binary.Base64;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class OrderServlet extends HttpServlet {

    private static final long serialVersionUID = -1450599121936722735L;

    static final Logger LOGGER = LoggerFactory.getLogger(OrderServlet.class);

    @Override
    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        doPost(req, resp);
    }

    @Override
    protected void doPost(final HttpServletRequest req, final HttpServletResponse resp)
            throws ServletException, IOException {

        //	商户编号(唯一标识)
        String merchantId = req.getParameter("merchantId");
        //订单金额
        String orderAmount = req.getParameter("orderAmount");
        //	订单币种
        String orderCurrency = req.getParameter("orderCurrency");
        //订单号
        String requestId = req.getParameter("requestId");
        //客户端ip
        String clientIp = req.getParameter("clientIp");
        //	通知地址
        String notifyUrl = req.getParameter("notifyUrl");
        //回调地址
        String callbackUrl = req.getParameter("callbackUrl");
        //服务商id
        String partnerId = req.getParameter("partnerId");
        //备注
        String remark = req.getParameter("remark");
        //支付方式编码
        String paymentModeCode = req.getParameter("paymentModeCode");
        //支付宝授权码
        String authCode = req.getParameter("authCode");//支付场景
        //微信appId
        String appId = req.getParameter("appId");
        //微信openId
        String openId = req.getParameter("openId");
        //productDetails(商品信息)
        //splitMark(分账标识)
        String splitMark = req.getParameter("splitMark");
        //payer(身份信息)可选项
        //超时时间
        String timeout = req.getParameter("timeout");
        //商户会员Id
        String merchantUserId = req.getParameter("merchantUserId");
        //绑卡Id
        String bindCardId = req.getParameter("bindCardId");
        //	报备序列号
        String reportSerialNo = req.getParameter("reportSerialNo");
        //报备终端号
        String reportTerminalNo = req.getParameter("reportTerminalNo");
        //applePay用户卡号信息
        String apCardNo = req.getParameter("apCardNo");
        //applePay用户交易数据
        String apUserData = req.getParameter("apUserData");
        //applePay用户信息
        String apTransData = req.getParameter("apTransData");
        //applePayToken
        String paymentToken = req.getParameter("paymentToken");
        //	项目id
        String projectId = req.getParameter("projectId");
        //限定账户类型
        String limitAccType = req.getParameter("limitAccType");
        //付款人姓名
        String payerName = req.getParameter("payerName");
        //手机号码
        String phoneNum = req.getParameter("phoneNum");
        //证件号
        String idNum = req.getParameter("idNum");
        //证件类型
        String idType = req.getParameter("idType");
        //银行卡号
        String bankCardNum = req.getParameter("bankCardNum");
        //email------（payer，身份信息）
        String email = req.getParameter("email");
        String interestType = req.getParameter("interestType");//请选择付息方式
        String suppBankCodes = req.getParameter("suppBankCodes");//限定银行
        String limitNum = req.getParameter("limitNum");//限定分期期数
        String storeNo = req.getParameter("storeNo");//门店编号
        String storeName = req.getParameter("storeName");//门店名称

        String subsidyMark = req.getParameter("subsidyMark");//补贴标识
        String subsidyAmount= req.getParameter("subsidyAmount");//补贴金额

        //hmac(参数签名)配置文件生成

        OrderBuilder builder = new OrderBuilder(merchantId);
        builder.setRequestId(requestId)
                .setOrderAmount(orderAmount)
                .setOrderCurrency(orderCurrency)
                .setNotifyUrl(notifyUrl)
                .setCallbackUrl(callbackUrl)
                .setRemark(remark)
                .setPaymentModeCode(paymentModeCode)
                .setNotifyUrl(notifyUrl)
                .setAuthCode(authCode)
                .setMerchantUserId(merchantUserId)
                .setBindCardId(bindCardId);


        if(StringUtils.isNotBlank(clientIp) ){
            builder.setClientIp(clientIp);
        }

        builder.setTimeout(timeout);
        builder.setPaymentToken(paymentToken);
        LOGGER.info("paymentToken++++++++++++++:{}", paymentToken);
        builder.setAppId(appId);
        builder.setOpenId(openId);
        builder.setApCardNo(apCardNo);
        builder.setApTransData(apTransData);
        builder.setApUserData(apUserData);
        builder.setReportSerialNo(reportSerialNo);
        builder.setReportTerminalNo(reportTerminalNo);
        builder.setPartnerId(partnerId);
        builder.setProjectId(projectId);
        builder.setSplitMark(splitMark);


        //productDetails(商品信息)
        String jsonPDStr = req.getParameter("hiddenPD").trim();
        LOGGER.info("productDetail++++++++++++++" + jsonPDStr);
        JSONArray productDetailArray = JSONObject.parseArray(jsonPDStr);
        ProductDetail productDetail = new ProductDetail();
        for (Object o : productDetailArray) {
            productDetail = JSONObject.parseObject(o.toString(), ProductDetail.class);
            builder.addProductDetail(productDetail);
        }

        //payer(身份信息)可选项
        Payer payer = new Payer();
        payer.setName(payerName);
        payer.setPhoneNum(phoneNum);
        payer.setBankCardNum(bankCardNum);
        payer.setIdNum(idNum);
        payer.setIdType(idType);
        payer.setEmail(email);
        builder.setPayer(payer);

        //分期支付参数
        InstalmentParams instalmentParams = new InstalmentParams();
        instalmentParams.setInterestType(interestType);
        instalmentParams.setSuppBankCodes(suppBankCodes);
        instalmentParams.setLimitNum(limitNum);
        instalmentParams.setStoreNo(storeNo);
        instalmentParams.setStoreName(storeName);
        builder.setInstalmentParams(instalmentParams);


        builder.setSubsidyMark(subsidyMark);
        builder.setSubsidyAmount(subsidyAmount);

        //补贴
        String subsidyDetail = req.getParameter("subsidyDetail").trim();
        if(StringUtils.isNotBlank(subsidyDetail)){
            String jsonSubsidyOrder = req.getParameter("subsidyDetail").trim();
            LOGGER.info("jsonSubsidyOrder:{}",jsonSubsidyOrder);
            JSONArray subsidyOrderArray = null;
            if(StringUtils.isNotBlank(jsonSubsidyOrder)){
                subsidyOrderArray = JSONObject.parseArray(jsonSubsidyOrder);
            }
            LOGGER.info("subsidyOrderArray:{}",subsidyOrderArray);
            if(subsidyOrderArray != null){
                for(Object o:subsidyOrderArray){
                    SubsidyOrder subsidyOrder = JSONObject.parseObject(o.toString(), SubsidyOrder.class);
                    builder.addSubsidyDetail(subsidyOrder);
                }
            }
        }



        final PrintWriter out = resp.getWriter();

        if (StringUtils.isBlank(merchantId)) {
            out.println("参数异常</br>");
            out.println("商户编号不能为空");
            return;
        } else {
            if (merchantId.length() != 9) {
                out.println("参数异常</br>");
                out.println("商户编号长度必须为9");
                return;
            }
        }

        try {
            OnlinePayOrderExecuter executer = new OnlinePayOrderExecuter();

            System.setProperty("https.protocols", "TLSv1.2,TLSv1.1,SSLv3");
            executer.bothOrder(builder, new ResultListenerAdpater() {
                /**
                 * 提交成功，不代表支付成功
                 */
                @Override
                public void success(JSONObject jsonObject) {
                    LOGGER.debug("success jsonObject:[" + jsonObject + "]");
                    if (jsonObject.get("scanCode") != null) {
                        try {
                            HttpSession session = req.getSession();
                            OrderResponse orderResponse = new OrderResponse();
                            orderResponse.setHmac(jsonObject.getString("hmac"));
                            orderResponse.setMerchantId(jsonObject.getString("merchantId"));
                            orderResponse.setRequestId(jsonObject.getString("requestId"));
                            orderResponse.setStatus(jsonObject.getString("status"));

                            //
                            String scanCodeStr = jsonObject.getString("scanCode");
                            orderResponse.setScanCode(Base64.decodeBase64(scanCodeStr));

                            session.setAttribute("orderResponse", orderResponse);
                            resp.sendRedirect("scancode.jsp");
                        } catch (Exception e) {
                            out.println("响应异常</br>");
                            out.println(e.toString());
                        }
                    } else if (jsonObject.get("jsString") != null) {
                        //微信公众号支付
                        try {
                            HttpSession session = req.getSession();
                            session.setAttribute("jsString", jsonObject.get("jsString"));
                            resp.sendRedirect("wechatjsapi.jsp");
                        } catch (Exception e) {
                            out.println("响应异常</br>");
                            out.println(e.toString());
                        }
                    }
                    out.println("提交成功</br>");
                    out.println(jsonObject);
                }

                @Override
                public void redirect(JSONObject jsonObject, String redirectUrl) throws IOException {
                    resp.sendRedirect(redirectUrl);
                    LOGGER.debug("redirectUrl:[" + redirectUrl + "]");
                }
            });
        } catch (ResponseException e) {
            out.println("响应异常</br>");
            out.println(e.toString());
        } catch (HmacVerifyException e) {
            out.println("签名验证异常</br>");
            out.println(e.toString());
        } catch (RequestException e) {
            out.println("请求异常</br>");
            out.println(e.toString());
        } catch (UnknownException e) {
            out.println("未知异常</br>");
            out.println(e.toString());
        }
    }
}
