/*
 * Project Name:upay-sdk-web
 * File Name:RefundServlet.java
 * Package Name:com.upay.sdk.onlinepay.v_2.RefundServlet
 * Date:2016-08-15 15:52:29
 * Copyright (c) 2016, upay All Rights Reserved.
 */

package com.upay.sdk.onlinepay;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.upay.sdk.entity.SubsidyOrder;
import com.upay.sdk.entity.SubsidyRefundOrder;
import com.upay.sdk.exception.HmacVerifyException;
import com.upay.sdk.exception.RequestException;
import com.upay.sdk.exception.ResponseException;
import com.upay.sdk.exception.UnknownException;
import com.upay.sdk.executer.ResultListenerAdpater;
import com.upay.sdk.onlinepay.builder.RefundBuilder;
import com.upay.sdk.onlinepay.executer.OnlinePayOrderExecuter;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;


public class RefundServlet extends HttpServlet {

    static final Logger LOGGER = LoggerFactory.getLogger(RefundServlet.class);

    @Override
    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        doPost(req, resp);
    }

    @Override
    protected void doPost(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        //商户编号
        String merchantId = req.getParameter("merchantId");
        //退款订单号(提交的订单号必须在自身平台交易中唯一)
        String requestId = req.getParameter("requestId");
        //金额
        String amount = req.getParameter("amount");
        //原订单流水号（原订单的serialNumber）
        String orderId = req.getParameter("orderId");
        //	备注
        String remark = req.getParameter("remark");
        //	通知地址V3结尾
        String notifyUrl = req.getParameter("notifyUrl");
        //退款补贴标识
        String  refundSubsidy = req.getParameter("refundSubsidy");
        //退款补贴金额
        String subsidyMoney = req.getParameter("subsidyMoney");

        RefundBuilder builder = new RefundBuilder(merchantId);
        builder.setRequestId(requestId)
                .setAmount(amount)
                .setOrderId(orderId)
                .setRemark(remark)
                .setNotifyUrl(notifyUrl);
        builder.setRefundSubsidy(refundSubsidy);
        builder.setSubsidyMoney(subsidyMoney);


        //补贴
        String subsidyDetail = req.getParameter("refundSubsidyDetail").trim();
        if(StringUtils.isNotBlank(subsidyDetail)){
            String jsonSubsidyResundOrder = req.getParameter("refundSubsidyDetail").trim();
            LOGGER.info("jsonSubsidyRefundOrder:{}",jsonSubsidyResundOrder);
            JSONArray subsidyRefundOrderArray = null;
            if(StringUtils.isNotBlank(jsonSubsidyResundOrder)){
                subsidyRefundOrderArray = JSONObject.parseArray(jsonSubsidyResundOrder);
            }
            LOGGER.info("subsidyRefundOrderArray:{}",subsidyRefundOrderArray);
            if(subsidyRefundOrderArray != null){
                for(Object o:subsidyRefundOrderArray){
                    SubsidyRefundOrder subsidyRefundOrder = JSONObject.parseObject(o.toString(), SubsidyRefundOrder.class);
                    builder.addRefundSubsidyDetail(subsidyRefundOrder);
                }
            }
        }




        final PrintWriter out = resp.getWriter();
        OnlinePayOrderExecuter executer = new OnlinePayOrderExecuter();

        try {
            executer.bothRefund(builder, new ResultListenerAdpater() {
                @Override
                public void success(JSONObject jsonObject) {
                    out.println("处理成功！<br/>");
                    String result = jsonObject.toJSONString();
                    out.print(result);
                }

                @Override
                public void failure(JSONObject jsonObject) {
                    out.println("处理失败！<br/>");
                    String result = jsonObject.toJSONString();
                    out.print(result);
                }

                @Override
                public void pending(JSONObject jsonObject) {
                    out.println("待处理！<br/>");
                    String result = jsonObject.toJSONString();
                    out.print(result);
                }
            });
        } catch (ResponseException e) {
            out.println("响应异常</br>");
            out.println(e.toString());
        } catch (HmacVerifyException e) {
            out.println("签名验证异常</br>");
            out.println(e.toString());
        } catch (RequestException e) {
            out.println("请求异常</br>");
            out.println(e.toString());
        } catch (UnknownException e) {
            out.println("未知异常</br>");
            out.println(e.toString());
        }
    }
}
