/*
 * Project Name:upay-sdk-web
 * File Name:SplitOrderQueryServlet.java
 * Package Name:com.upay.sdk.onlinepay.v_3.SplitOrderQueryServlet
 * Date:2020-07-11 09:34:28
 * Copyright (c) 2020, upay All Rights Reserved.
 */

package com.upay.sdk.onlinepay;

import com.alibaba.fastjson.JSONObject;
import com.upay.sdk.exception.HmacVerifyException;
import com.upay.sdk.exception.RequestException;
import com.upay.sdk.exception.ResponseException;
import com.upay.sdk.exception.UnknownException;
import com.upay.sdk.executer.ResultListenerAdpater;
import com.upay.sdk.onlinepay.builder.SplitQueryBuilder;
import com.upay.sdk.onlinepay.executer.OnlinePayOrderExecuter;
import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class SplitOrderQueryServlet extends HttpServlet {


    static final Logger LOGGER = LoggerFactory.getLogger(SplitOrderQueryServlet.class);
    private static final long serialVersionUID = -679848935977904231L;

    @Override
    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        doPost(req, resp);
    }

    @Override
    protected void doPost(final HttpServletRequest req, final HttpServletResponse resp)
            throws ServletException, IOException {

        //merchantId商户编号
        String merchantId = req.getParameter("merchantId");
        final PrintWriter out = resp.getWriter();
        if (StringUtils.isBlank(merchantId)) {
            out.println("参数异常</br>");
            out.println("商户编号不能为空");
            return;
        } else {
            if (merchantId.length() != 9) {
                out.println("参数异常</br>");
                out.println("商户编号长度必须为9");
                return;
            }
        }
        //退款订单号
        String requestId = req.getParameter("requestId");
        //分账明细订单号
        String subSplitRequestId = req.getParameter("subSplitRequestId");
        //服务商id
        String partnerId = req.getParameter("partnerId");
        SplitQueryBuilder builder = new SplitQueryBuilder(merchantId);
        builder.setRequestId(requestId);
        builder.setSubSplitRequestId(subSplitRequestId);
        builder.setPartnerId(partnerId);
        try {
            OnlinePayOrderExecuter executer = new OnlinePayOrderExecuter();
            executer.bothSplitOrderQuery(builder, new ResultListenerAdpater() {
                /**
                 * 提交成功
                 */
                @Override
                public void success(JSONObject jsonObject) {
                    LOGGER.info("success jsonObject:{}", jsonObject);
                    out.println("提交成功</br>");
                    out.println(jsonObject);
                }
            });
        } catch (ResponseException e) {
            out.println("响应异常</br>");
            out.println(e.toString());
        } catch (HmacVerifyException e) {
            out.println("签名验证异常</br>");
            out.println(e.toString());
        } catch (RequestException e) {
            out.println("请求异常</br>");
            out.println(e.toString());
        } catch (UnknownException e) {
            out.println("未知异常</br>");
            out.println(e.toString());
        }
    }
}
