/*
 * Project Name:upay-sdk-web
 * File Name:SplitOrderServlet.java
 * Package Name:com.upay.sdk.onlinepay.v_3.SplitOrderServlet
 * Date:2020-07-08 10:59:58
 * Copyright (c) 2020, upay All Rights Reserved.
 */

package com.upay.sdk.onlinepay;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.upay.sdk.entity.SplitDetail;
import com.upay.sdk.exception.HmacVerifyException;
import com.upay.sdk.exception.RequestException;
import com.upay.sdk.exception.ResponseException;
import com.upay.sdk.exception.UnknownException;
import com.upay.sdk.executer.ResultListenerAdpater;
import com.upay.sdk.onlinepay.builder.SplitOrderBuilder;
import com.upay.sdk.onlinepay.executer.OnlinePayOrderExecuter;
import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class SplitOrderServlet extends HttpServlet {


    static final Logger LOGGER = LoggerFactory.getLogger(SplitOrderServlet.class);
    private static final long serialVersionUID = -679848935977904231L;

    @Override
    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        doPost(req, resp);
    }

    @Override
    protected void doPost(final HttpServletRequest req, final HttpServletResponse resp)
            throws ServletException, IOException {

        final String agent = req.getHeader("User-agent");//判断客户端
        LOGGER.info("agent:{}", agent);

        String merchantId = req.getParameter("merchantId");
        final PrintWriter out = resp.getWriter();
        if (StringUtils.isBlank(merchantId)) {
            out.println("参数异常</br>");
            out.println("商户编号不能为空");
            return;
        } else {
            if (merchantId.length() != 9) {
                out.println("参数异常</br>");
                out.println("商户编号长度必须为9");
                return;
            }
        }
        //原订单流水号（serialNumber）是交易流水号而不是银行流水号
        String orderId = req.getParameter("orderId");
        //分账订单号
        String requestId = req.getParameter("requestId");
        //此处为退款金额
        String totalSplitAmount = req.getParameter("totalSplitAmount");
        //服务商id
        String partnerId = req.getParameter("partnerId");
        //通知地址
        String notifyUrl = req.getParameter("notifyUrl");

        SplitOrderBuilder builder = new SplitOrderBuilder(merchantId);
        builder.setOrderId(orderId)
                .setRequestId(requestId)
                .setTotalSplitAmount(totalSplitAmount)
                .setNotifyUrl(notifyUrl);
        builder.setPartnerId(partnerId);
        String jsonPDStr = req.getParameter("hiddenSplitRecord").trim();

        LOGGER.info("splitDetail:{}", jsonPDStr);
        JSONArray splitDetailArray = JSONObject.parseArray(jsonPDStr);

        SplitDetail splitDetail = new SplitDetail();
        for (Object o : splitDetailArray) {
            splitDetail = JSONObject.parseObject(o.toString(), SplitDetail.class);
            builder.addSplitDetails(splitDetail);
        }

        try {
            OnlinePayOrderExecuter executer = new OnlinePayOrderExecuter();
            executer.bothSplitOrder(builder, new ResultListenerAdpater() {
                /**
                 * 提交成功
                 */
                @Override
                public void success(JSONObject jsonObject) {
                    LOGGER.info("success jsonObject:{}", jsonObject);
                    out.println("提交成功</br>");
                    out.println(jsonObject);
                }
            });
        } catch (ResponseException e) {
            out.println("响应异常</br>");
            out.println(e.toString());
        } catch (HmacVerifyException e) {
            out.println("签名验证异常</br>");
            out.println(e.toString());
        } catch (RequestException e) {
            out.println("请求异常</br>");
            out.println(e.toString());
        } catch (UnknownException e) {
            out.println("未知异常</br>");
            out.println(e.toString());
        }
    }
}
